@@ -41,10 +41,15 @@ has_neo4j_api <- function() {
 # @param url points to csv resource
 read_csv_online <- function(url, ...) {
     if (has_api()) {
-      as.data.frame(suppressMessages(readr::read_csv(url)))
-    } else {
-      stop(paste("GloBI data services are not available at [", globi_api_url, "]. Are you connected to the internet?", sep = ""))
+      res <- suppressWarnings(suppressMessages(as.data.frame(readr::read_csv(url))))
+
+      # Drop rows with all NAs
+      res <- res[rowSums(is.na(res)) != ncol(res), ]
+
+      return(res)
     }
+
+    stop(paste("GloBI data services are not available at [", globi_api_url, "]. Are you connected to the internet?", sep = ""))
 }
 
 #' Get Species Interaction from GloBI
